@@ -66,9 +66,9 @@ def AddBaseCol (colName, colType):
         raise Exception(f"Tuser base error: There is no Tuser config file.")
 
 def main ():
-    if sys.argv[1] == "quik":
+    if sys.argv[1] == "quick":
         QuikBaseCreate()
     if sys.argv[1] == "struct":
         GetBaseStruct()
-    if sys.argv[1] == "addfield":
+    if sys.argv[1] == "add-field":
         AddBaseCol(sys.argv[2], sys.argv[3])
\ No newline at end of file
